#
# spec file for package swaks
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           swaks
Version:        20240103.0
Release:        2.1
Summary:        Swiss Army Knife for SMTP
License:        GPL-2.0-only
Group:          Productivity/Networking/Email/Clients
URL:            https://jetmore.org/john/code/swaks/
Source:         https://jetmore.org/john/code/swaks/files/swaks-%{version}.tar.gz
Requires:       perl(IO::Socket::IP)
Requires:       perl(Net::DNS)
Requires:       perl(Net::SSLeay)
BuildArch:      noarch

%description
Swaks is a scriptable, transaction-oriented SMTP test
tool. Features include:

* SMTP extensions including TLS, authentication, pipelining, and
  XCLIENT
* Protocols including SMTP, ESMTP, and LMTP
* Transports including UNIX-domain sockets, internet-domain sockets
  (IPv4 and IPv6), and pipes to spawned processes
* Completely scriptable configuration, with option specification via
  environment variables, configuration files, and command line

%prep
%autosetup -p1

%build

%install
install -D -m 0755 swaks %{buildroot}%{_bindir}/%{name}
install -dD -m 0755 %{buildroot}%{_mandir}/man1
pod2man --center=SWAKS --section=1 swaks %{buildroot}%{_mandir}/man1/%{name}.1

%files
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.gz
%license LICENSE.txt
%doc README.txt doc/*.txt

%changelog
* Wed Jun 12 2024 Dirk Stoecker <opensuse@dstoecker.de>
- remove package name based perl requires
* Mon Jan 15 2024 Pedro Monreal <pmonreal@suse.com>
- Update to 20240103.0:
  * Full changelog in: http://jetmore.org/john/code/swaks/versions.html
  * New Features:
  * Added --cc and --bcc options
  * Numerous TLS debugging and verification improvements
  * Debug output contains whether a client cert was requested and whether
    one was sent
  * Add new options --tls-verify-ca and --tls-verify-host to differentiate
    between types of certificate verification (--tls-verify does both)
  * Add --tls-target option to allow setting of hostname to be used in
    hostname verification.  This is useful in some inet debugging situations
    and required to do hostname verification with --socket or --pipe
  * Add --tls-chain (#60, initial implementation by Wolfgang Karall-Ahlborn)
  * Add --tls-get-peer-chain option (analogous to --tls-get-peer-cert, #73)
  * Certificate debug now includes all client and peer certs, it a chain
    was used (#73)
  * Certificate debug now includes notAfter, commonName, and subjectAltName
  * Notable Changes:
  * --output-file, --output-file-stderr, and --output-file-stdout now truncate
    the specified file if it already exists
  * Documentation improvements
  * Extensive test harness improvements
  * Add new stop-point XCLIENT-HELO to address lack of specificity when
    mixing XCLIENT usage with the HELO stop-point
  * Add new stop-point PROXY
  * Use IO::Socket::IP by default.  Will still use IO::Socket::INET/INET6
    to cover transition, but this is deprecated and will be removed in the
    future (#43)
  * TLS session debug information is now printed even if we decide not to
    continue the session (eg for failed verification)
  * Previously-deprecated functionality to allow some options to be either
    a filename or a literal string has been removed.  Using the '@' sigil is
    now the only was to specify file contents
  * Previously-deprecated -g option removed
  * Notable Bugs Fixed:
  * TLS certificate verification did not always work.  It should now
- Remove deprecated dependency on IO::Socket::INET6
- Use https for URL and sources.
* Sun Nov 19 2023 Alex Bihlmaier <thalunil@kallisti.at>
- user request: manpage added
  https://bugzilla.opensuse.org/show_bug.cgi?id=1193140
* Mon Nov  6 2023 Marcus Rueckert <mrueckert@suse.de>
- 🙄 also require perl-IO-Socket-INET6 to ipv6 works out of the box
* Sat Oct  7 2023 Marcus Rueckert <mrueckert@suse.de>
- some feature require perl-Net-DNS
* Thu Jan 21 2021 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descrpition. Wrap description.
* Thu Oct 22 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 20201014.0
  https://www.jetmore.org/john/blog/2020/10/swaks-release-20201014-0-available/
  https://www.jetmore.org/john/blog/2020/10/swaks-release-20201010-0-available/
* Thu Oct 22 2020 Marcus Rueckert <mrueckert@suse.de>
- require perl-Net-SSLeay to enable SSL support out of the box
* Mon Sep 14 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 20190914.0
  https://www.jetmore.org/john/blog/2019/10/swaks-release-20190914-0-available/
* Wed Sep 12 2018 Marcus Rueckert <mrueckert@suse.de>
- initial package 20170101.0
